@@ -1,11 +1,12 @@
 """
     Code for the Slumber client connector.
 """
-from django.conf import settings
-
+import logging
 from urllib import urlencode
 from urlparse import urljoin
 
+from django.conf import settings
+
 from slumber._caches import CLIENT_INSTANCE_CACHE, \
     MODEL_URL_TO_SLUMBER_MODEL
 from slumber.connector.api import get_model
@@ -16,6 +17,19 @@ from slumber.server import get_slumber_service, get_slumber_directory, \
     get_slumber_services, get_slumber_local_url_prefix, get_slumber_root
 
 
+def _get_slumber_authn_name():
+    """Used in the implementation of get_auth_name so it can be easily
+    patched.
+    """
+    return getattr(settings, 'SLUMBER_AUTHN_NAME', get_slumber_service())
+def get_slumber_authn_name():
+    """Return the user name that is to be used for authenticating Slumber
+    requests to the back end. This user name is used together with the
+    SECRET_KEY and defaults to the service name.
+    """
+    return _get_slumber_authn_name()
+
+
 class ServiceConnector(object):
     """Connects to a service.
     """
@@ -25,9 +39,15 @@ class ServiceConnector(object):
     def __getattr__(self, attr_name):
         """Fetch the application list from the Slumber directory on request.
         """
+        logging.debug("Looking for attribute %s on %s for directory %s",
+            attr_name, self, self._directory)
         if not self._directory:
+            logging.debug("Raising AttributeError as _directory is falsey")
             raise AttributeError(attr_name)
         _, json = get(self._directory)
+        logging.debug(
+            "Looking for attribute %s on %s resulted in these applications %s",
+            attr_name, self, json)
         # Pylint gets confused by the JSON object
         # pylint: disable=E1103
         json_apps = json.get('apps', {})
@@ -67,6 +87,9 @@ class Client(ServiceConnector):
     """The first level of the Slumber client connector.
     """
     def __init__(self, directory=None):
+        client_apps = getattr(settings, 'SLUMBER_CLIENT_APPS', [])
+        for app in client_apps:
+            __import__(app, globals(), locals(), ['slumber_client'])
         services = get_slumber_services(directory)
         if not services:
             if not directory:
